@@ -36,7 +36,6 @@ from urllib3.exceptions import MaxRetryError
 from elyra.metadata.manager import MetadataManager
 from elyra.pipeline.component import Component
 from elyra.pipeline.component import ComponentParser
-from elyra.pipeline.component_registry import CachedComponentRegistry
 from elyra.pipeline.component_registry import ComponentRegistry
 from elyra.pipeline.pipeline import GenericOperation
 from elyra.pipeline.pipeline import Operation
@@ -59,11 +58,13 @@ class PipelineProcessorRegistry(SingletonConfigurable):
             try:
                 # instantiate an actual instance of the processor
                 processor_instance = processor.load()(self.root_dir, parent=kwargs.get('parent'))  # Load an instance
-                self.log.info(f'Registering processor "{processor}" with type -> {processor_instance.type}')
+                self.log.info(f'Registering {processor.name} processor '
+                              f'"{processor.module_name}.{processor.object_name}"...')
                 self.add_processor(processor_instance)
             except Exception as err:
                 # log and ignore initialization errors
-                self.log.error('Error registering processor "{}" - {}'.format(processor, err))
+                self.log.error(f'Error registering {processor.name} processor '
+                               f'"{processor.module_name}.{processor.object_name}" - {err}')
 
     def add_processor(self, processor):
         self.log.debug(f'Registering processor {processor.type}')
@@ -303,11 +304,15 @@ class RuntimePipelineProcessor(PipelineProcessor):
     def component_parser(self) -> ComponentParser:
         return self._component_parser
 
+    @property
+    def component_registry(self) -> ComponentRegistry:
+        return self._component_registry
+
     def __init__(self, root_dir: str, component_parser: ComponentParser, **kwargs):
         super().__init__(root_dir, **kwargs)
 
         self._component_parser = component_parser
-        self._component_registry = CachedComponentRegistry(component_parser)
+        self._component_registry = ComponentRegistry(component_parser)
 
     def _get_dependency_archive_name(self, operation):
         artifact_name = os.path.basename(operation.filename)
@@ -374,19 +379,19 @@ class RuntimePipelineProcessor(PipelineProcessor):
                            format(operation.name), exc_info=True)
             raise ex from ex
 
-    def _get_metadata_configuration(self, namespace, name=None):
+    def _get_metadata_configuration(self, schemaspace, name=None):
         """
-        Retrieve associated metadata configuration based on namespace provided and optional instance name
+        Retrieve associated metadata configuration based on schemaspace provided and optional instance name
         :return: metadata in json format
         """
         try:
             if not name:
-                return MetadataManager(namespace=namespace).get_all()
+                return MetadataManager(schemaspace=schemaspace).get_all()
             else:
-                return MetadataManager(namespace=namespace).get(name)
+                return MetadataManager(schemaspace=schemaspace).get(name)
         except BaseException as err:
-            self.log.error('Error retrieving metadata configuration for {}'.format(name), exc_info=True)
-            raise RuntimeError('Error retrieving metadata configuration for {}', err) from err
+            self.log.error(f'Error retrieving metadata configuration for {name}', exc_info=True)
+            raise RuntimeError(f'Error retrieving metadata configuration for {name}', err) from err
 
     def _collect_envs(self, operation: GenericOperation, **kwargs) -> Dict:
         """
@@ -416,8 +421,14 @@ class RuntimePipelineProcessor(PipelineProcessor):
         JSON should be converted to the appropriate Dict format, if possible. If a Dict cannot be formed,
         log and return stripped string value.
         """
-        converted_dict = None
+        if not value:
+            return {}
+
         value = value.strip()
+        if value == "None":
+            return {}
+
+        converted_dict = None
         if value.startswith('{') and value.endswith('}'):
             try:
                 converted_dict = ast.literal_eval(value)
@@ -437,7 +448,13 @@ class RuntimePipelineProcessor(PipelineProcessor):
         should be converted to the appropriate List format, if possible. If a List cannot be formed,
         log and return stripped string value.
         """
+        if not value:
+            return []
+
         value = value.strip()
+        if value == "None":
+            return []
+
         converted_list = None
         if value.startswith('[') and value.endswith(']'):
             try:
